@@ -12,6 +12,9 @@ def wtforms_translation_string_factory(domain):
 
         def __str__(self):
             return self.lts.translate(self.msg, mapping=self.mapping)
+
+        def __mod__(self, data):
+            return self.__str__() % data
     
     return _WTFormsLazyTranslationString
 
